@@ -9,7 +9,7 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.EC2 1.25.3\nVersion:         1.25.3\nBuilder version:"
+        "Type annotations for boto3.EC2 1.26.0\nVersion:         1.26.0.post1\nBuilder version:"
         " 7.11.10\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2\nOther"
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.25.3")
+    print("1.26.0.post1")
 
 
 def main() -> None:
