@@ -27,6 +27,7 @@ __all__ = (
     "ActivityStatusType",
     "AddressAttributeNameType",
     "AddressFamilyType",
+    "AddressTransferStatusType",
     "AffinityType",
     "AllocationStateType",
     "AllocationStrategyType",
@@ -86,6 +87,7 @@ __all__ = (
     "DefaultTargetCapacityTypeType",
     "DeleteFleetErrorCodeType",
     "DeleteQueuedReservedInstancesErrorCodeType",
+    "DescribeAddressTransfersPaginatorName",
     "DescribeAddressesAttributePaginatorName",
     "DescribeByoipCidrsPaginatorName",
     "DescribeCapacityReservationFleetsPaginatorName",
@@ -480,6 +482,7 @@ AccountAttributeNameType = Literal["default-vpc", "supported-platforms"]
 ActivityStatusType = Literal["error", "fulfilled", "pending_fulfillment", "pending_termination"]
 AddressAttributeNameType = Literal["domain-name"]
 AddressFamilyType = Literal["ipv4", "ipv6"]
+AddressTransferStatusType = Literal["accepted", "disabled", "pending"]
 AffinityType = Literal["default", "host"]
 AllocationStateType = Literal[
     "available",
@@ -610,6 +613,7 @@ DeleteFleetErrorCodeType = Literal[
 DeleteQueuedReservedInstancesErrorCodeType = Literal[
     "reserved-instances-id-invalid", "reserved-instances-not-in-queued-state", "unexpected-error"
 ]
+DescribeAddressTransfersPaginatorName = Literal["describe_address_transfers"]
 DescribeAddressesAttributePaginatorName = Literal["describe_addresses_attribute"]
 DescribeByoipCidrsPaginatorName = Literal["describe_byoip_cidrs"]
 DescribeCapacityReservationFleetsPaginatorName = Literal["describe_capacity_reservation_fleets"]
@@ -2265,6 +2269,7 @@ ResourceServiceName = Literal[
     "sqs",
 ]
 PaginatorName = Literal[
+    "describe_address_transfers",
     "describe_addresses_attribute",
     "describe_byoip_cidrs",
     "describe_capacity_reservation_fleets",
